==> omb-skel-1.0.0-4-any.pkg.tar.zst: etc/skel/.config/oh-my-bash/themes/THEMES.md <==
## `90210`

[![](90210/90210-dark.png)](90210/90210-dark.png)

## `ab+simple`

[![](absimple/absimple-bash.png)](absimple/absimple-bash.png)

## `agnoster`

[![](agnoster/agnoster-bash-sshot.png)](agnoster/agnoster-bash-sshot.png)
[![](agnoster/agnoster-dark.png)](agnoster/agnoster-dark.png)

## `axin`

[![](axin/axin-dark.png)](axin/axin-dark.png)

## `bakke`

[![](bakke/bakke-dark.png)](bakke/bakke-dark.png)

## `binaryanomaly`

[![](binaryanomaly/binaryanomaly-dark.png)](binaryanomaly/binaryanomaly-dark.png)

## `bobby`

[![](bobby/bobby-dark.png)](bobby/bobby-dark.png)

## `bobby-python`

[![](bobby-python/bobby-python-dark.png)](bobby-python/bobby-python-dark.png)

## `brainy`

[![](brainy/brainy-dark.png)](brainy/brainy-dark.png)

## `brunton`

[![](brunton/brunton-dark.png)](brunton/brunton-dark.png)

## `candy`

[![](candy/candy-dark.png)](candy/candy-dark.png)

## `clean`

[![](clean/clean-dark.png)](clean/clean-dark.png)

## `cooperkid`

[![](cooperkid/cooperkid-dark.png)](cooperkid/cooperkid-dark.png)

## `cupcake`

[![](cupcake/cupcake-dark.png)](cupcake/cupcake-dark.png)

## `demula`

[![](demula/demula-dark.png)](demula/demula-dark.png)

## `dos`

[![](dos/dos-dark.png)](dos/dos-dark.png)

## `doubletime`

[![](doubletime/doubletime-dark.png)](doubletime/doubletime-dark.png)

## `doubletime_multiline`

[![](doubletime_multiline/doubletime_multiline-dark.png)](doubletime_multiline/doubletime_multiline-dark.png)

## `doubletime_multiline_pyonly`

[![](doubletime_multiline_pyonly/doubletime_multiline_pyonly-dark.png)](doubletime_multiline_pyonly/doubletime_multiline_pyonly-dark.png)

## `dulcie`

[![](dulcie/dulcie-dark.png)](dulcie/dulcie-dark.png)

## `duru`

[![](duru/duru-dark.png)](duru/duru-dark.png)

## `edsonarios`

[![](edsonarios/edsonarios-dark.png)](edsonarios/edsonarios-dark.png)

## `emperor`

[![](emperor/emperor-dark.png)](emperor/emperor-dark.png)

## `envy`

[![](envy/envy-dark.png)](envy/envy-dark.png)

## `font`

[![](font/font-dark.png)](font/font-dark.png)

## `gallifrey`

[![](gallifrey/gallifrey-dark.png)](gallifrey/gallifrey-dark.png)

## `half-life`

[![](half-life/half-life.theme.png)](half-life/half-life.theme.png)

## `hawaii50`

[![](hawaii50/hawaii50-dark.png)](hawaii50/hawaii50-dark.png)

## `iterate`

[![](iterate/iterate-dark.png)](iterate/iterate-dark.png)

## `kitsune`

[![](kitsune/kitsune-dark.png)](kitsune/kitsune-dark.png)

## `luan`

[![](luan/luan-dark.png)](luan/luan-dark.png)

## `mairan`

[![](mairan/mairan-dark.png)](mairan/mairan-dark.png)

## `mbriggs`

[![](mbriggs/mbriggs-dark.png)](mbriggs/mbriggs-dark.png)

## `minimal`

[![](minimal/minimal-dark.png)](minimal/minimal-dark.png)

## `minimal-gh`

[![](minimal-gh/minimal-gh-dark.png)](minimal-gh/minimal-gh-dark.png)

## `modern`

[![](modern/modern-dark.png)](modern/modern-dark.png)

## `modern-t`

[![](modern-t/modern-t-dark.png)](modern-t/modern-t-dark.png)

## `morris`

[![](morris/morris-dark.png)](morris/morris-dark.png)

## `n0qorg`

[![](n0qorg/n0qorg-dark.png)](n0qorg/n0qorg-dark.png)

## `nwinkler`

[![](nwinkler/nwinkler-dark.png)](nwinkler/nwinkler-dark.png)

## `nwinkler_random_colors`

[![](nwinkler_random_colors/screenshot.png)](nwinkler_random_colors/screenshot.png)
[![](nwinkler_random_colors/nwinkler_random_colors-dark.png)](nwinkler_random_colors/nwinkler_random_colors-dark.png)

## `pete`

[![](pete/pete-dark.png)](pete/pete-dark.png)

## `powerbash10k`

[![](powerbash10k/powerbash10k-dark.png)](powerbash10k/powerbash10k-dark.png)

## `powerline`

[![](powerline/powerline-dark.png)](powerline/powerline-dark.png)

## `powerline-icon`

[![](powerline-icon/powerline-icon-dark.png)](powerline-icon/powerline-icon-dark.png)

## `powerline-light`

[![](powerline-light/powerline-light.png)](powerline-light/powerline-light.png)

## `powerline-multiline`

[![](powerline-multiline/powerline-multiline-dark.png)](powerline-multiline/powerline-multiline-dark.png)

## `powerline-naked`

[![](powerline-naked/powerline-naked-dark.png)](powerline-naked/powerline-naked-dark.png)

## `powerline-plain`

[![](powerline-plain/powerline-plain-dark.png)](powerline-plain/powerline-plain-dark.png)

## `primer`

[![](primer/primer-dark.png)](primer/primer-dark.png)

## `pro`

[![](pro/pro-dark.png)](pro/pro-dark.png)

## `pure`

[![](pure/pure-dark.png)](pure/pure-dark.png)

## `purity`

[![](purity/purity-dark.png)](purity/purity-dark.png)

## `pzq`

[![](pzq/pzq-dark.png)](pzq/pzq-dark.png)

## `rainbowbrite`

[![](rainbowbrite/rainbowbrite-dark.png)](rainbowbrite/rainbowbrite-dark.png)

## `rana`

[![](rana/rana-dark.png)](rana/rana-dark.png)

## `rjorgenson`

[![](rjorgenson/rjorgenson-dark.png)](rjorgenson/rjorgenson-dark.png)

## `robbyrussell`

[![](robbyrussell/robbyrussell-dark.png)](robbyrussell/robbyrussell-dark.png)

## `roderik`

[![](roderik/roderik-dark.png)](roderik/roderik-dark.png)

## `rr`

[![](rr/rr-dark.png)](rr/rr-dark.png)

## `sexy`

[![](sexy/sexy-dark.png)](sexy/sexy-dark.png)

## `simple`

[![](simple/simple-dark.png)](simple/simple-dark.png)

## `sirup`

[![](sirup/sirup-dark.png)](sirup/sirup-dark.png)

## `slick`

[![](slick/slick-dark.png)](slick/slick-dark.png)

## `standard`

[![](standard/standard-dark.png)](standard/standard-dark.png)

## `tonka`

[![](tonka/tonka-dark.png)](tonka/tonka-dark.png)

## `tonotdo`

[![](tonotdo/tonotdo-dark.png)](tonotdo/tonotdo-dark.png)

## `tylenol`

[![](tylenol/tylenol-dark.png)](tylenol/tylenol-dark.png)

## `vscode`

[![](vscode/vscode-dark.png)](vscode/vscode-dark.png)

## `wanelo`

[![](wanelo/wanelo-dark.png)](wanelo/wanelo-dark.png)

## `zitron`

[![](zitron/zitron-dark.png)](zitron/zitron-dark.png)

## `zork`

[![](zork/zork-dark.png)](zork/zork-dark.png)

==> omb-skel-1.1.1-1-any.pkg.tar.zst: etc/skel/.config/oh-my-bash/themes/THEMES.md <==
## `90210`

[![](90210/90210-dark.png)](90210/90210-dark.png)

## `ab+simple`

[![](absimple/absimple-bash.png)](absimple/absimple-bash.png)

## `agnoster`

[![](agnoster/agnoster-bash-sshot.png)](agnoster/agnoster-bash-sshot.png)
[![](agnoster/agnoster-dark.png)](agnoster/agnoster-dark.png)

## `axin`

[![](axin/axin-dark.png)](axin/axin-dark.png)

## `bakke`

[![](bakke/bakke-dark.png)](bakke/bakke-dark.png)

## `binaryanomaly`

[![](binaryanomaly/binaryanomaly-dark.png)](binaryanomaly/binaryanomaly-dark.png)

## `bobby`

[![](bobby/bobby-dark.png)](bobby/bobby-dark.png)

## `bobby-python`

[![](bobby-python/bobby-python-dark.png)](bobby-python/bobby-python-dark.png)

## `brainy`

[![](brainy/brainy-dark.png)](brainy/brainy-dark.png)

## `brunton`

[![](brunton/brunton-dark.png)](brunton/brunton-dark.png)

## `candy`

[![](candy/candy-dark.png)](candy/candy-dark.png)

## `clean`

[![](clean/clean-dark.png)](clean/clean-dark.png)

## `cooperkid`

[![](cooperkid/cooperkid-dark.png)](cooperkid/cooperkid-dark.png)

## `copied-duru`

[![](copied-duru/copied-duru-dark.png)](copied-duru/copied-duru-dark.png)

## `cupcake`

[![](cupcake/cupcake-dark.png)](cupcake/cupcake-dark.png)

## `demula`

[![](demula/demula-dark.png)](demula/demula-dark.png)

## `developer`

[![](developer/developer_theme_2024_02_09.png)](developer/developer_theme_2024_02_09.png)

## `dos`

[![](dos/dos-dark.png)](dos/dos-dark.png)

## `doubletime`

[![](doubletime/doubletime-dark.png)](doubletime/doubletime-dark.png)

## `doubletime_multiline`

[![](doubletime_multiline/doubletime_multiline-dark.png)](doubletime_multiline/doubletime_multiline-dark.png)

## `doubletime_multiline_pyonly`

[![](doubletime_multiline_pyonly/doubletime_multiline_pyonly-dark.png)](doubletime_multiline_pyonly/doubletime_multiline_pyonly-dark.png)

## `dulcie`

[![](dulcie/dulcie-dark.png)](dulcie/dulcie-dark.png)

## `duru`

[![](duru/duru-dark.png)](duru/duru-dark.png)

## `edsonarios`

[![](edsonarios/edsonarios-dark.png)](edsonarios/edsonarios-dark.png)

## `emperor`

[![](emperor/emperor-dark.png)](emperor/emperor-dark.png)

## `envy`

[![](envy/envy-dark.png)](envy/envy-dark.png)

## `font`

[![](font/font-dark.png)](font/font-dark.png)

## `gallifrey`

[![](gallifrey/gallifrey-dark.png)](gallifrey/gallifrey-dark.png)

## `half-life`

[![](half-life/half-life.theme.png)](half-life/half-life.theme.png)

## `hawaii50`

[![](hawaii50/hawaii50-dark.png)](hawaii50/hawaii50-dark.png)

## `ht`

[![](ht/ht-dark.png)](ht/ht-dark.png)

## `iterate`

[![](iterate/iterate-dark.png)](iterate/iterate-dark.png)

## `kitsune`

[![](kitsune/kitsune-dark.png)](kitsune/kitsune-dark.png)

## `lambda`

[![](lambda/lambda-dark.png)](lambda/lambda-dark.png)

## `luan`

[![](luan/luan-dark.png)](luan/luan-dark.png)

## `mairan`

[![](mairan/mairan-dark.png)](mairan/mairan-dark.png)

## `mbriggs`

[![](mbriggs/mbriggs-dark.png)](mbriggs/mbriggs-dark.png)

## `minimal`

[![](minimal/minimal-dark.png)](minimal/minimal-dark.png)

## `minimal-gh`

[![](minimal-gh/minimal-gh-dark.png)](minimal-gh/minimal-gh-dark.png)

## `modern`

[![](modern/modern-dark.png)](modern/modern-dark.png)

## `modern-t`

[![](modern-t/modern-t-dark.png)](modern-t/modern-t-dark.png)

## `morris`

[![](morris/morris-dark.png)](morris/morris-dark.png)

## `n0qorg`

[![](n0qorg/n0qorg-dark.png)](n0qorg/n0qorg-dark.png)

## `nekolight`

[![](nekolight/nekolight-dark.jpg)](nekolight/nekolight-dark.jpg)

## `nekonight`

[![](nekonight/nekonight-dark.jpg)](nekonight/nekonight-dark.jpg)

## `nekonight_moon`

[![](nekonight_moon/nekonight_moon-dark.jpg)](nekonight_moon/nekonight_moon-dark.jpg)

## `nwinkler`

[![](nwinkler/nwinkler-dark.png)](nwinkler/nwinkler-dark.png)

## `nwinkler_random_colors`

[![](nwinkler_random_colors/screenshot.png)](nwinkler_random_colors/screenshot.png)
[![](nwinkler_random_colors/nwinkler_random_colors-dark.png)](nwinkler_random_colors/nwinkler_random_colors-dark.png)

## `pete`

[![](pete/pete-dark.png)](pete/pete-dark.png)

## `powerbash10k`

[![](powerbash10k/powerbash10k-dark.png)](powerbash10k/powerbash10k-dark.png)

## `powerline`

[![](powerline/powerline-dark.png)](powerline/powerline-dark.png)

## `powerline-icon`

[![](powerline-icon/powerline-icon-dark.png)](powerline-icon/powerline-icon-dark.png)

## `powerline-light`

[![](powerline-light/powerline-light.png)](powerline-light/powerline-light.png)

## `powerline-multiline`

[![](powerline-multiline/powerline-multiline-dark.png)](powerline-multiline/powerline-multiline-dark.png)

## `powerline-naked`

[![](powerline-naked/powerline-naked-dark.png)](powerline-naked/powerline-naked-dark.png)

## `powerline-plain`

[![](powerline-plain/powerline-plain-dark.png)](powerline-plain/powerline-plain-dark.png)

## `powerline-wizard`

[![](powerline-wizard/powerline-wizard-dark.png)](powerline-wizard/powerline-wizard-dark.png)

## `primer`

[![](primer/primer-dark.png)](primer/primer-dark.png)

## `pro`

[![](pro/pro-dark.png)](pro/pro-dark.png)

## `pure`

[![](pure/pure-dark.png)](pure/pure-dark.png)

## `purity`

[![](purity/purity-dark.png)](purity/purity-dark.png)

## `pzq`

[![](pzq/pzq-dark.png)](pzq/pzq-dark.png)

## `rainbowbrite`

[![](rainbowbrite/rainbowbrite-dark.png)](rainbowbrite/rainbowbrite-dark.png)

## `rana`

[![](rana/rana-dark.png)](rana/rana-dark.png)

## `rjorgenson`

[![](rjorgenson/rjorgenson-dark.png)](rjorgenson/rjorgenson-dark.png)

## `robbyrussell`

[![](robbyrussell/robbyrussell-dark.png)](robbyrussell/robbyrussell-dark.png)

## `roderik`

[![](roderik/roderik-dark.png)](roderik/roderik-dark.png)

## `rr`

[![](rr/rr-dark.png)](rr/rr-dark.png)

## `sexy`

[![](sexy/sexy-dark.png)](sexy/sexy-dark.png)

## `simple`

[![](simple/simple-dark.png)](simple/simple-dark.png)

## `sirup`

[![](sirup/sirup-dark.png)](sirup/sirup-dark.png)

## `slick`

[![](slick/slick-dark.png)](slick/slick-dark.png)

## `standard`

[![](standard/standard-dark.png)](standard/standard-dark.png)

## `tonka`

[![](tonka/tonka-dark.png)](tonka/tonka-dark.png)

## `tonotdo`

[![](tonotdo/tonotdo-dark.png)](tonotdo/tonotdo-dark.png)

## `tylenol`

[![](tylenol/tylenol-dark.png)](tylenol/tylenol-dark.png)

## `vscode`

[![](vscode/vscode-dark.png)](vscode/vscode-dark.png)

## `wanelo`

[![](wanelo/wanelo-dark.png)](wanelo/wanelo-dark.png)

## `zitron`

[![](zitron/zitron-dark.png)](zitron/zitron-dark.png)

## `zork`

[![](zork/zork-dark.png)](zork/zork-dark.png)
